# josh22pdf

## This is a test

pip3 list
pip3 install setuptools wheel twine
python3 setup.py sdist bdist_wheel
twine upload dist/*
twine upload dist/*
pydoc3 math
pydoc3 joshpdf.pdf2text
pydoc3 -w joshpdf.pdf2text